@@ -1,6 +1,6 @@
 package Import::Base;
 # ABSTRACT: Import a set of modules into the calling module
-$Import::Base::VERSION = '0.010';
+$Import::Base::VERSION = '0.011';
 use strict;
 use warnings;
 use mro ();
@@ -51,21 +51,43 @@ sub import {
     $args{package} = scalar caller(0);
 
     # Prepare the modules to load
+    # First pass determines the order to load
     my ( @first_load, @last_load );
     my @cb_args = ( \@bundles, \%args );
     my @modules = $class->modules( @cb_args );
     while ( @modules ) {
         if ( ref $modules[0] eq 'CODE' ) {
-            unshift @modules, shift( @modules )->( @cb_args );
+            push @first_load, shift @modules;
             next;
         }
 
         my $module = shift @modules;
-        if ( ref $modules[0] eq 'CODE' ) {
-            unshift @modules, shift( @modules )->( @cb_args );
+        my $imports = ref $modules[0] eq 'ARRAY' ? shift @modules : [];
+
+        # Determine the module order
+        if ( $module =~ /^</ ) {
+            $module =~ s/^<//;
+            unshift @first_load, $module => $imports;
+        }
+        elsif ( $module =~ /^>/ ) {
+            $module =~ s/^>//;
+            push @last_load, $module => $imports;
+        }
+        else {
+            push @first_load, $module => $imports;
+        }
+    }
+
+    # Second pass loads the modules
+    my @loads = ( @first_load, @last_load );
+    while ( my $load = shift @loads ) {
+        if ( ref $load eq 'CODE' ) {
+            unshift @loads, $load->( @cb_args );
+            next;
         }
 
-        my $imports = ref $modules[0] eq 'ARRAY' ? shift @modules : [];
+        my $module = $load;
+        my $imports = ref $loads[0] eq 'ARRAY' ? shift @loads : [];
 
         if ( exists $exclude->{ $module } ) {
             if ( defined $exclude->{ $module } ) {
@@ -81,23 +103,6 @@ sub import {
             }
         }
 
-        # Determine the module order
-        if ( $module =~ /^</ ) {
-            $module =~ s/^<//;
-            unshift @first_load, [ $module => $imports ];
-        }
-        elsif ( $module =~ /^>/ ) {
-            $module =~ s/^>//;
-            push @last_load, [ $module => $imports ];
-        }
-        else {
-            push @first_load, [ $module => $imports ];
-        }
-    }
-
-    for my $pair ( @first_load, @last_load ) {
-        my ( $module, $imports ) = @{ $pair };
-
         my $method = 'import::into';
         if ( $module =~ /^-/ ) {
             $method = 'unimport::out_of';
@@ -120,7 +125,7 @@ Import::Base - Import a set of modules into the calling module
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -361,18 +366,17 @@ If you need even more control over the order, consider the L</"Dynamic API">.
 =head2 Subref Callbacks
 
 To get a little bit of dynamic support in the otherwise static module lists, you may
-add sub references to generate modules or imports.
+add sub references to generate module imports.
 
     package My::Base;
     use base 'Import::Base';
     our @IMPORT_MODULES = (
         sub {
             my ( $bundles, $args ) = @_;
-            return qw( strict warnings );
-        },
-        feature => sub {
-            my ( $bundles, $args ) = @_;
-            return [qw( :5.20 )];
+            return (
+                qw( strict warnings ),
+                feature => [qw( :5.20 )],
+            );
         },
     );
 
@@ -380,6 +384,11 @@ add sub references to generate modules or imports.
 
 Plain strings are module names. Array references are arguments to import.
 
+B<NOTE:> Subrefs cannot return modules with C<E<lt>> or C<E<gt>> to control
+ordering. Subrefs are run after the order has already been determined, while
+the imports are being executed. Subrefs can assume that imports before them
+have already been completed.
+
 =head2 Subref Arguments
 
 Sub references get an arrayref of bundles being requested, and a hashref of
@@ -393,6 +402,25 @@ Using C<package>, a subref could check or alter C<@ISA>, work with the object's
 metaclass (if you're using one), or export additional symbols not set up for
 export.
 
+Here's an example for applying a L<Moo::Role> when importing a bundle:
+
+    package My::Base;
+    use base 'Import::Base';
+    our %IMPORT_BUNDLES = (
+        'Plugin' => [
+            'Moo',
+            # Plugins require the "My::Plugin" role
+            sub {
+                my ( $bundles, $args ) = @_;
+                Moo::Role->apply_role_to_package( $args->{package}, 'My::Plugin' );
+                return;
+            },
+        ],
+    );
+
+    package My::Custom::Plugin;
+    use My::Base 'Plugin';
+
 =head2 Custom Arguments
 
 When using L</"Subref Callbacks">, you can add additional arguments to the
@@ -594,7 +622,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Doug Bell.
+This software is copyright (c) 2015 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
